==> haskell-doctest-exitcode-stdio-0.0-136-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest-exitcode-stdio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 doctest-exitcode-stdio
version:              0.0
visibility:           public
id:                   doctest-exitcode-stdio-0.0-Lk1Hbud2uut8H6ScpRQ89M
key:                  doctest-exitcode-stdio-0.0-Lk1Hbud2uut8H6ScpRQ89M
license:              BSD-3-Clause
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:               Henning Thielemann <haskell@henning-thielemann.de>
homepage:             https://hub.darcs.net/thielema/doctest-exitcode-stdio/
synopsis:             Run doctest'\''s in a Cabal.Test.exitcode-stdio environment
description:
    Run doctest'\''s in a Cabal.Test.exitcode-stdio environment.
    For use with the @doctest-extract@ utility.
    Normally, you should not need to import a module from this package,
    only generated code will do this.

category:             Testing
abi:                  6ff65621d440f936b1a94cc5ad1c73d7
exposed:              True
exposed-modules:      Test.DocTest.Driver
import-dirs:          /usr/lib/ghc-9.2.8/site-local/doctest-exitcode-stdio-0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/doctest-exitcode-stdio-0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-exitcode-stdio
hs-libraries:         HSdoctest-exitcode-stdio-0.0-Lk1Hbud2uut8H6ScpRQ89M
depends:
    QuickCheck-2.14.3-JVpLupMbhPgL6XTp3rPxED base-4.16.4.0
    doctest-lib-0.1.1-FwOSPrD6AGwGSQnWv9xqms transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-doctest-exitcode-stdio/html/doctest-exitcode-stdio.haddock

haddock-html:         /usr/share/doc/haskell-doctest-exitcode-stdio/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doctest-exitcode-stdio-0.0-140-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest-exitcode-stdio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 doctest-exitcode-stdio
version:              0.0
visibility:           public
id:                   doctest-exitcode-stdio-0.0-CZluKIHhsTh1mGvVLRg76C
key:                  doctest-exitcode-stdio-0.0-CZluKIHhsTh1mGvVLRg76C
license:              BSD-3-Clause
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:               Henning Thielemann <haskell@henning-thielemann.de>
homepage:             https://hub.darcs.net/thielema/doctest-exitcode-stdio/
synopsis:             Run doctest'\''s in a Cabal.Test.exitcode-stdio environment
description:
    Run doctest'\''s in a Cabal.Test.exitcode-stdio environment.
    For use with the @doctest-extract@ utility.
    Normally, you should not need to import a module from this package,
    only generated code will do this.

category:             Testing
abi:                  2e3e74ae75d1af415171c71dde523365
exposed:              True
exposed-modules:      Test.DocTest.Driver
import-dirs:          /usr/lib/ghc-9.2.8/site-local/doctest-exitcode-stdio-0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/doctest-exitcode-stdio-0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-exitcode-stdio
hs-libraries:         HSdoctest-exitcode-stdio-0.0-CZluKIHhsTh1mGvVLRg76C
depends:
    QuickCheck-2.14.3-AB831W8sF74KL3cz7DxP1X base-4.16.4.0
    doctest-lib-0.1.1.1-JOCXoj4nLevAcQktoJxInB transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-doctest-exitcode-stdio/html/doctest-exitcode-stdio.haddock

haddock-html:         /usr/share/doc/haskell-doctest-exitcode-stdio/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
